import { Logger } from './logger';
import { Level } from './level';
import { Display } from './display';
import { contain } from './include';
import { Helpers } from './helper';
if (Helpers.isNode) {
}
export class Log {
    static create(name, ...level) {
        let i;
        if (Log.instances[name] === undefined) {
            i = new Logger(name, Log.getRandomColor(), Log.isDevelopmentMode, level, Log.isMutedModule(name), Log.levels.length > 0 ? Log.fixedWidth : undefined);
            Log.instances[name] = i;
        }
        else {
            i = Log.instances[name];
        }
        return i;
    }
    static getRandomColor() {
        if (Helpers.isNode) {
        }
        let letters = '012345'.split('');
        let color = '#';
        color += letters[Math.round(Math.random() * 5)];
        letters = '0123456789ABCDEF'.split('');
        for (let i = 0; i < 5; i++) {
            color += letters[Math.round(Math.random() * 15)];
        }
        if (color === undefined)
            return this.getRandomColor();
        return color;
    }
    static display(name, data, incomming, moduleName) {
        if (!contain(Log.levels, incomming))
            return;
        if (incomming === Level.DATA) {
            Display.msg(name, data, moduleName, Log.instances[moduleName].color, Level.DATA, Log.instances[moduleName].fixedWidth);
        }
        if (incomming === Level.ERROR) {
            Display.msg(name, data, moduleName, Log.instances[moduleName].color, Level.ERROR, Log.instances[moduleName].fixedWidth);
        }
        if (incomming === Level.INFO) {
            Display.msg(name, data, moduleName, Log.instances[moduleName].color, Level.INFO, Log.instances[moduleName].fixedWidth);
        }
        if (incomming === Level.WARN) {
            Display.msg(name, data, moduleName, Log.instances[moduleName].color, Level.WARN, Log.instances[moduleName].fixedWidth);
        }
    }
    static onlyLevel(...level) {
        if (Log._logOnly) {
            throw '[ng2-logger] You should use funcion onlyLevel only once';
        }
        if (!Log._logOnly) {
            Log._logOnly = true;
        }
        Log.levels = Array.isArray(level) ? level : [level];
        for (const logName in Log.instances) {
            if (Log.instances.hasOwnProperty(logName)) {
                const element = Log.instances[logName];
                element['allowed'] = Log.levels;
            }
        }
    }
    static onlyModules(...modules) {
        if (Log._logModules) {
            throw '[ng2-logger] You should use funcion onlyModules only once';
        }
        if (!Log._logModules) {
            Log._logModules = true;
        }
        if (modules.length === 0)
            return;
        Log.modules = modules;
        // console.log('only log this', Log.modules)
        Log.muteAllOtherModules();
    }
    static isMutedModule(moduleName) {
        if (Log.modules.length == 0)
            return false;
        if (!contain(Log.modules, moduleName))
            return true;
        return false;
    }
    static muteAllOtherModules() {
        for (var moduleName in Log.instances) {
            if (!contain(Log.modules, moduleName))
                Log.instances[moduleName].mute();
        }
    }
    static setProductionMode() {
        if (Log.modeIsSet) {
            Log.modeIsSet = false;
            throw '[ng2-logger] Production mode is already set';
        }
        else {
            Log.modeIsSet = true;
            setTimeout(() => {
                if (Log.modeIsSet && console !== undefined && console.clear !== undefined) {
                    console.clear();
                    console.log = () => { };
                    console.error = () => { };
                    console.warn = () => { };
                    console.info = () => { };
                }
            });
            Logger.isProductionMode = true;
            Log.isDevelopmentMode = false;
        }
    }
}
Log.instances = {};
Log.fixedWidth = 0;
Log._logOnly = false;
Log.levels = [];
Log._logModules = false;
Log.modules = [];
Log.isDevelopmentMode = true;
Log.modeIsSet = false;
//# sourceMappingURL=log.js.map